// Subscription Page JavaScript

document.addEventListener('DOMContentLoaded', function() {
    // Plan selection functionality
    const planButtons = document.querySelectorAll('.select-plan-btn');
    const checkoutSection = document.getElementById('checkout-section');
    const selectedPlanName = document.getElementById('selected-plan-name');
    const selectedPlanPrice = document.getElementById('selected-plan-price');
    const summaryPlanName = document.getElementById('summary-plan-name');
    const summaryPlanPrice = document.getElementById('summary-plan-price');
    const summaryTotalPrice = document.getElementById('summary-total-price');

    // Payment tab switching
    const paymentTabs = document.querySelectorAll('.payment-tab');
    const paymentForms = document.querySelectorAll('.payment-form');

    // Initialize Stripe
    const stripe = Stripe('pk_test_TYooMQauvdEDq54NiTphI7jx'); // Replace with your publishable key
    const elements = stripe.elements();
    const cardElement = elements.create('card', {
        style: {
            base: {
                fontSize: '16px',
                color: '#32325d',
                fontFamily: '"Helvetica Neue", Helvetica, sans-serif',
                fontSmoothing: 'antialiased',
                '::placeholder': {
                    color: '#aab7c4'
                }
            },
            invalid: {
                color: '#fa755a',
                iconColor: '#fa755a'
            }
        }
    });

    // Mount the card Element
    cardElement.mount('#card-element');

    // Handle real-time validation errors from the card Element
    cardElement.on('change', function(event) {
        const displayError = document.getElementById('card-errors');
        if (event.error) {
            displayError.textContent = event.error.message;
        } else {
            displayError.textContent = '';
        }
    });

    // Initialize PayPal
    paypal.Buttons({
        createOrder: function(data, actions) {
            // Get the selected plan price
            const planPrice = document.getElementById('summary-plan-price').textContent;
            
            // Create the order
            return actions.order.create({
                purchase_units: [{
                    amount: {
                        value: planPrice
                    }
                }],
                application_context: {
                    shipping_preference: 'NO_SHIPPING'
                }
            });
        },
        onApprove: function(data, actions) {
            // Show a loading indicator
            document.body.classList.add('loading');
            
            // Capture the funds from the transaction
            return actions.order.capture().then(function(details) {
                // Call your server to save the transaction
                return fetch('/paypal/process-subscription', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify({
                        orderID: data.orderID,
                        payerID: data.payerID,
                        payerEmail: document.getElementById('paypal-email').value,
                        payerName: document.getElementById('paypal-name').value,
                        payerCompany: document.getElementById('paypal-company').value,
                        planName: document.getElementById('summary-plan-name').textContent,
                        planPrice: document.getElementById('summary-plan-price').textContent
                    })
                })
                .then(response => response.json())
                .then(data => {
                    // Hide loading indicator
                    document.body.classList.remove('loading');
                    
                    if (data.success) {
                        // Redirect to success page
                        window.location.href = '/subscription/success?id=' + data.subscriptionId;
                    } else {
                        // Show error message
                        alert('There was a problem processing your subscription. Please try again.');
                    }
                })
                .catch(error => {
                    // Hide loading indicator
                    document.body.classList.remove('loading');
                    console.error('Error:', error);
                    alert('There was a problem processing your subscription. Please try again.');
                });
            });
        },
        onError: function(err) {
            console.error('PayPal Error:', err);
            alert('There was a problem with PayPal. Please try again or use a different payment method.');
        }
    }).render('#paypal-button-container');

    // Handle plan selection
    planButtons.forEach(button => {
        button.addEventListener('click', function() {
            const plan = this.getAttribute('data-plan');
            const price = this.getAttribute('data-price');
            
            // Update checkout section
            selectedPlanName.textContent = plan.charAt(0).toUpperCase() + plan.slice(1);
            selectedPlanPrice.textContent = price;
            summaryPlanName.textContent = plan.charAt(0).toUpperCase() + plan.slice(1);
            summaryPlanPrice.textContent = price;
            summaryTotalPrice.textContent = price;
            
            // Show checkout section
            checkoutSection.style.display = 'block';
            
            // Scroll to checkout section
            checkoutSection.scrollIntoView({ behavior: 'smooth' });
        });
    });

    // Handle payment tab switching
    paymentTabs.forEach(tab => {
        tab.addEventListener('click', function() {
            // Remove active class from all tabs and forms
            paymentTabs.forEach(t => t.classList.remove('active'));
            paymentForms.forEach(f => f.classList.remove('active'));
            
            // Add active class to clicked tab
            this.classList.add('active');
            
            // Show corresponding form
            const paymentMethod = this.getAttribute('data-payment');
            document.getElementById(paymentMethod + '-form').classList.add('active');
        });
    });

    // Handle Stripe form submission
    const stripeForm = document.getElementById('stripe-payment-form');
    stripeForm.addEventListener('submit', function(event) {
        event.preventDefault();
        
        const submitButton = document.getElementById('stripe-submit-button');
        const buttonText = document.getElementById('button-text');
        const spinner = document.getElementById('spinner');
        
        // Disable the submit button to prevent repeated clicks
        submitButton.disabled = true;
        buttonText.style.display = 'none';
        spinner.classList.remove('hidden');
        
        // Create a payment method and confirm payment
        stripe.createPaymentMethod({
            type: 'card',
            card: cardElement,
            billing_details: {
                name: document.getElementById('name').value,
                email: document.getElementById('email').value
            }
        }).then(function(result) {
            if (result.error) {
                // Show error to your customer
                const errorElement = document.getElementById('card-errors');
                errorElement.textContent = result.error.message;
                
                // Re-enable the submit button
                submitButton.disabled = false;
                buttonText.style.display = 'inline';
                spinner.classList.add('hidden');
            } else {
                // Send the payment method ID to your server
                fetch('/stripe/process-subscription', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify({
                        paymentMethodId: result.paymentMethod.id,
                        customerName: document.getElementById('name').value,
                        customerEmail: document.getElementById('email').value,
                        customerCompany: document.getElementById('company').value,
                        planName: document.getElementById('summary-plan-name').textContent,
                        planPrice: document.getElementById('summary-plan-price').textContent
                    })
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        // Redirect to success page
                        window.location.href = '/subscription/success?id=' + data.subscriptionId;
                    } else {
                        // Show error message
                        const errorElement = document.getElementById('card-errors');
                        errorElement.textContent = data.error;
                        
                        // Re-enable the submit button
                        submitButton.disabled = false;
                        buttonText.style.display = 'inline';
                        spinner.classList.add('hidden');
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    
                    // Show error message
                    const errorElement = document.getElementById('card-errors');
                    errorElement.textContent = 'There was a problem processing your subscription. Please try again.';
                    
                    // Re-enable the submit button
                    submitButton.disabled = false;
                    buttonText.style.display = 'inline';
                    spinner.classList.add('hidden');
                });
            }
        });
    });

    // FAQ toggle functionality
    const faqItems = document.querySelectorAll('.faq-item');
    faqItems.forEach(item => {
        const question = item.querySelector('.faq-question');
        const answer = item.querySelector('.faq-answer');
        const toggle = item.querySelector('.faq-toggle');
        
        // Hide all answers initially
        answer.style.display = 'none';
        
        question.addEventListener('click', function() {
            // Toggle active class
            item.classList.toggle('active');
            
            // Toggle answer visibility
            if (answer.style.display === 'none') {
                answer.style.display = 'block';
                toggle.innerHTML = '<i class="fas fa-minus"></i>';
            } else {
                answer.style.display = 'none';
                toggle.innerHTML = '<i class="fas fa-plus"></i>';
            }
        });
    });

    // Testimonial slider functionality
    const testimonials = document.querySelectorAll('.testimonial');
    const dots = document.querySelectorAll('.dot');
    const prevButton = document.querySelector('.slider-prev');
    const nextButton = document.querySelector('.slider-next');
    let currentSlide = 0;
    
    // Show first testimonial initially
    showTestimonial(currentSlide);
    
    function showTestimonial(index) {
        // Hide all testimonials
        testimonials.forEach(testimonial => {
            testimonial.style.display = 'none';
        });
        
        // Remove active class from all dots
        dots.forEach(dot => {
            dot.classList.remove('active');
        });
        
        // Show current testimonial and activate corresponding dot
        testimonials[index].style.display = 'block';
        dots[index].classList.add('active');
    }
    
    // Previous button click
    prevButton.addEventListener('click', function() {
        currentSlide--;
        if (currentSlide < 0) {
            currentSlide = testimonials.length - 1;
        }
        showTestimonial(currentSlide);
    });
    
    // Next button click
    nextButton.addEventListener('click', function() {
        currentSlide++;
        if (currentSlide >= testimonials.length) {
            currentSlide = 0;
        }
        showTestimonial(currentSlide);
    });
    
    // Dot click
    dots.forEach((dot, index) => {
        dot.addEventListener('click', function() {
            currentSlide = index;
            showTestimonial(currentSlide);
        });
    });
    
    // Auto-advance slides every 5 seconds
    setInterval(function() {
        currentSlide++;
        if (currentSlide >= testimonials.length) {
            currentSlide = 0;
        }
        showTestimonial(currentSlide);
    }, 5000);
});
